% define_process.m - defines linear models of the quadruple-tank process
s = tf('s');

A = 4.9; % Tank cross-section [cm^2]

a = 0.03; % Outlet hole cross-sections [cm^2]
a1 = a;
a2 = a;
a3 = a;
a4 = a;

k = 1.6; % Pump constants [cm^3 V^{-1} s^{-1}]
k1 = k;
k2 = k;
kc = 10/16; % Measurement constant [V cm^{-1}]
g = 981; % Acceleration of gravitation [cm s^{-2}]

h10 = 10; % Operating point in lower tank 1 [cm]
h20 = 10; % Operating point in lower tank 2 [cm]
u10 = a1/k1*sqrt(2*g*h10); % Corresponding pump signal [V]
u20 = a2/k2*sqrt(2*g*h20); % Corresponding pump signal [V]

% Minimum-phase case
gamma = 0.7;
gamma1 = gamma;
gamma2 = gamma;

h30 = ((1-gamma2)*k2*u20/a3)^2/(2*g);
h40 = ((1-gamma1)*k1*u10/a4)^2/(2*g);
T1 = A/a1*sqrt(2*h10/g);
T2 = A/a2*sqrt(2*h20/g);
T3 = A/a3*sqrt(2*h30/g);
T4 = A/a4*sqrt(2*h40/g);

Ap = [-1/T1 0 1/T3 0; 0 -1/T2 0 1/T4; 0 0 -1/T3 0; 0 0 0 -1/T4];
Bp = [gamma1*k1/A 0; 0 gamma2*k2/A; 0 (1-gamma2)*k2/A; (1-gamma1)*k1/A 0];
Cp = [kc 0 0 0; 0 kc 0 0];

Gmin = ss(Ap,Bp,Cp,0);

% Non-minimum-phase case
gamma = 0.3;
gamma1 = gamma;
gamma2 = gamma;

h30 = ((1-gamma2)*k2*u20/a3)^2/(2*g);
h40 = ((1-gamma1)*k1*u10/a4)^2/(2*g);
T1 = A/a1*sqrt(2*h10/g);
T2 = A/a2*sqrt(2*h20/g);
T3 = A/a3*sqrt(2*h30/g);
T4 = A/a4*sqrt(2*h40/g);

Ap = [-1/T1 0 1/T3 0; 0 -1/T2 0 1/T4; 0 0 -1/T3 0; 0 0 0 -1/T4];
Bp = [gamma1*k1/A 0; 0 gamma2*k2/A; 0 (1-gamma2)*k2/A; (1-gamma1)*k1/A 0];
Cp = [kc 0 0 0; 0 kc 0 0];

Gnonmin = ss(Ap,Bp,Cp,0);

init_quadtank

